# Running Gaussian 16 with failure allowed

Typically, a task will retry three times if the exit code is not zero. Sometimes, one may allow non-zero code. For example, when running large amounts of Gaussian 16 single-point calculation tasks, some of the Gaussian 16 tasks may throw SCF errors and return a non-zero code. One can append `||:` to the command:

```{literalinclude} ../../examples/task/g16.json
:language: json
:linenos:
```

This command ensures the task will always provide zero code.
